/* Everything */

/* License information */
#define QT_PRODUCT_LICENSEE "Free"
#define QT_PRODUCT_LICENSE  "qt-free"

/* Build key */
#define QT_BUILD_KEY "x86_64 CYGWIN_NT-10.0 g++-4.* full-config"

/* Machine byte-order */
#define Q_BIG_ENDIAN 4321
#define Q_LITTLE_ENDIAN 1234
#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
/* Compile time features */
#define QT_LARGEFILE_SUPPORT 64
#define QT_POINTER_SIZE 8
#ifndef QT_NO_IM_EXTENSIONS
# define QT_NO_IM_EXTENSIONS
#endif

